import junit.framework.TestCase;

public class TestRules extends TestCase
{
    public static void main(String[] args) throws Exception
    {
        junit.textui.TestRunner.run(TestRules.class);
    }

    public void testSell() throws Exception
    {
        Exchange theExchange = new Exchange();
        Collector c1 = new Collector(1000, true);
        Collector c2 = new Collector(200, false);

        assertEquals(c1.collectionCount(), 1000);
        assertEquals(c2.collectionCount(), 200);

        boolean result = theExchange.tradeFromSellerToBuyer(c1, c2, 10);
        assertTrue(result);

        assertEquals(c1.collectionCount(), 990);
        assertEquals(c2.collectionCount(), 210);

        theExchange.cleanUp();
    }

    public void testBigBuyerSmallSale() throws Exception
    {
        Exchange theExchange = new Exchange();
        Collector c1 = new Collector(1000, true);
        Collector c2 = new Collector(200, false);

        assertEquals(c1.collectionCount(), 1000);
        assertEquals(c2.collectionCount(), 200);

        boolean result = theExchange.tradeFromSellerToBuyer(c2, c1, 10);
        assertFalse(result);

        assertEquals(c1.collectionCount(), 1000);
        assertEquals(c2.collectionCount(), 200);
        theExchange.cleanUp();
    }

    public void testSellOnlyWhatYouHave() throws Exception
    {
        Exchange theExchange = new Exchange();
        Collector c1 = new Collector(1000, true);
        Collector c2 = new Collector(200, false);

        assertEquals(c1.collectionCount(), 1000);
        assertEquals(c2.collectionCount(), 200);

        boolean result = theExchange.tradeFromSellerToBuyer(c1, c2, 1010);
        assertFalse(result);

        assertEquals(c1.collectionCount(), 1000);
        assertEquals(c2.collectionCount(), 200);
        theExchange.cleanUp();
    }

    public void testBigBuyerAlwaysSellsToBigBuyer() throws Exception
    {
        Exchange theExchange = new Exchange();
        Collector c1 = new Collector(1000, true);
        Collector c2 = new Collector(200, true);

        assertEquals(c1.collectionCount(), 1000);
        assertEquals(c2.collectionCount(), 200);

        boolean result = theExchange.tradeFromSellerToBuyer(c2, c1, 10);
        assertTrue(result);

        assertEquals(c1.collectionCount(), 1010);
        assertEquals(c2.collectionCount(), 190);
        theExchange.cleanUp();
    }
}
